@@ -5,6 +5,7 @@ import unittest
 
 import flask
 from mock import patch
+from mock import MagicMock
 
 from amundsen_common.log import http_header_caller_retrieval
 from amundsen_common.log.http_header_caller_retrieval import HttpHeaderCallerRetrieval
@@ -13,12 +14,11 @@ app = flask.Flask(__name__)
 
 
 class ActionLogTest(unittest.TestCase):
-
     def test(self) -> None:
-        with app.test_request_context(), patch.object(http_header_caller_retrieval, 'request') as mock_request:
+        with app.test_request_context(), \
+                patch.object(http_header_caller_retrieval, 'request', new=MagicMock()) as mock_request:
             mock_request.headers.get.return_value = 'foo'
             actual = HttpHeaderCallerRetrieval().get_caller()
-
             self.assertEqual(actual, 'foo')
 
 
